Multiple Comparison Procedures
------------------------------

This module contains a set of bootstrap-based multiple comparison procedures.
These are designed to allow multiple models to be compared while controlling
a the `Familywise Error Rate <https://www.google.com/search?q=familywise+error+rate>`_,
which is similar to the size of a test.

.. module::arch.bootstrap

.. toctree::
    :maxdepth: 1

    Examples <multiple-comparison_examples.ipynb>
    Module Reference <multiple-comparison-reference>
    Background and References <background>






